#ifndef TESTBITMAPIMAGE_H_
#define TESTBITMAPIMAGE_H_

#include <cxxtest/TestSuite.h>

#include "BitmapImage.h"
#include "RGBPixel.h"

class TestBitmapImage : public CxxTest::TestSuite
{
public:
	void test_global_BitmapImage_BitmapImage() {
		BitmapImage* im1 = new BitmapImage(72, 57);
		TS_ASSERT_EQUALS(im1->getWidth(), 72);
		TS_ASSERT_EQUALS(im1->getHeight(), 57);
		delete im1;
	}

	void test_global_BitmapImage_BitmapImage_copy() {
		BitmapImage* im_orig = new BitmapImage(72, 57);
		RGBPixel pix1(24, 36, 48);
		RGBPixel pix2(45, 76, 98);
		im_orig->setPixel(3, 4, pix1);
		im_orig->setPixel(35, 56, pix2);
		BitmapImage* im_copy = new BitmapImage(*im_orig);
		TS_ASSERT_EQUALS( im_copy->getWidth(), 72);
		TS_ASSERT_EQUALS(im_copy->getHeight(), 57);
		RGBPixel pixq = im_copy->getPixel(3, 4);
		TS_ASSERT_EQUALS( pixq, pix1);
		pixq = im_copy->getPixel(35, 56);
		TS_ASSERT_EQUALS( pixq, pix2 );
		delete im_orig;
		delete im_copy;
	}

	void testSetGetPixel() {
		BitmapImage im1(2, 2);
		RGBPixel pix1(1, 1, 1);
		RGBPixel pix2(2, 2, 2);
		RGBPixel pix3(3, 3, 3);
		RGBPixel pix4(4, 4, 4);
		im1.setPixel(0, 0, pix4);
		im1.setPixel(0, 1, pix3);
		im1.setPixel(1, 0, pix2);
		im1.setPixel(1, 1, pix1);
		TS_ASSERT_EQUALS(im1.getPixel(0, 0), pix4);
		TS_ASSERT_EQUALS(im1.getPixel(0, 1), pix3);
		TS_ASSERT_EQUALS(im1.getPixel(1, 0), pix2);
		TS_ASSERT_EQUALS(im1.getPixel(1, 1), pix1);
	}

	void testOperator_equals() {
		BitmapImage im1(2, 2);
		RGBPixel pix1(1, 1, 1);
		RGBPixel pix2(2, 2, 2);
		RGBPixel pix3(3, 3, 3);
		RGBPixel pix4(4, 4, 4);
		im1.setPixel(0, 0, pix4);
		im1.setPixel(0, 1, pix3);
		im1.setPixel(1, 0, pix2);
		im1.setPixel(1, 1, pix1);
		BitmapImage im2(2,2);
		im2.setPixel(0, 0, pix4);
		im2.setPixel(0, 1, pix3);
		im2.setPixel(1, 0, pix2);
		im2.setPixel(1, 1, pix1);
		TS_ASSERT(im1 == im2);
	}

	void testOperator_assign() {
		BitmapImage im1(2, 2);
		RGBPixel pix1(1, 1, 1);
		RGBPixel pix2(2, 2, 2);
		RGBPixel pix3(3, 3, 3);
		RGBPixel pix4(4, 4, 4);
		im1.setPixel(0, 0, pix4);
		im1.setPixel(0, 1, pix3);
		im1.setPixel(1, 0, pix2);
		im1.setPixel(1, 1, pix1);
		BitmapImage im2(2,2);
		im2.setPixel(0, 0, pix1);
		im2.setPixel(0, 1, pix2);
		im2.setPixel(1, 0, pix3);
		im2.setPixel(1, 1, pix4);
		im2 = im1;
		TS_ASSERT_EQUALS(im2.getPixel(0, 0), pix4);
		TS_ASSERT_EQUALS(im2.getPixel(0, 1), pix3);
		TS_ASSERT_EQUALS(im2.getPixel(1, 0), pix2);
		TS_ASSERT_EQUALS(im2.getPixel(1, 1), pix1);
	}

};

#endif /*TESTBITMAPIMAGE_H_*/
